.. include:: /_includes/wip_prolog.rst

:mod:`stix.exploit_target` Module
==================================

.. module:: stix.exploit_target

Classes
-------

.. autoclass:: ExploitTarget
	:show-inheritance:
	:members:

.. autoclass:: PotentialCOAs
	:show-inheritance:
	:members:

.. autoclass:: RelatedExploitTargets
	:show-inheritance:
	:members:
